SegmentUsage

Struct SegmentUsage 

pub struct SegmentUsage {
    pub system_used: i32,
    pub instructions_used: i32,
    pub evidence_used: i32,
    pub memory_used: i32,
    pub tool_results_used: i32,
    pub history_used: i32,
}
Segment usage tracking.

Tracks how many tokens have been used in each segment.

Fields

system_used: i32

Tokens used in system segment

instructions_used: i32

Tokens used in instructions segment

evidence_used: i32

Tokens used in evidence segment

memory_used: i32

Tokens used in memory segment

tool_results_used: i32

Tokens used in tool results segment

history_used: i32

Tokens used in history segment

Implementations

Source

impl SegmentUsage

pub fn total(&self) -> i32

Get total tokens used across all segments.

pub fn for_segment(&self, segment: ContextSegment) -> i32

Get usage for a specific segment.

pub fn can_add( &self, segment: ContextSegment, tokens: i32, budget: &TokenBudget, ) -> bool

Check if we can add tokens to a segment.

pub fn add( &mut self, segment: ContextSegment, tokens: i32, budget: &TokenBudget, ) -> bool

Add tokens to a segment.

Returns true if successful, false if budget exceeded.

pub fn remaining(&self, segment: ContextSegment, budget: &TokenBudget) -> i32

Get remaining tokens in a segment.