pub struct StoredHandoff {
pub data: HandoffRecord,
pub status: HandoffStatus,
}Expand description
A handoff as stored in the database (status-agnostic).
When loading from the database, we don’t know the state at compile time.
Use the into_* methods to validate and convert to a typed handoff.
Fields
data: HandoffRecordstatus: HandoffStatusImplementations
Sourceimpl StoredHandoff
impl StoredHandoff
Sourcepub fn into_typed(self) -> LoadedHandoff
pub fn into_typed(self) -> LoadedHandoff
Convert to a typed handoff based on the stored status.
Sourcepub fn into_initiated(self) -> Result<Handoff<Initiated>, HandoffStateError>
pub fn into_initiated(self) -> Result<Handoff<Initiated>, HandoffStateError>
Try to convert to an initiated handoff.
Sourcepub fn into_accepted(
self,
) -> Result<Handoff<HandoffAccepted>, HandoffStateError>
pub fn into_accepted( self, ) -> Result<Handoff<HandoffAccepted>, HandoffStateError>
Try to convert to an accepted handoff.
Sourcepub fn data(&self) -> &HandoffRecord
pub fn data(&self) -> &HandoffRecord
Get the underlying data without state validation.
Sourcepub fn status(&self) -> HandoffStatus
pub fn status(&self) -> HandoffStatus
Get the current status.