pub struct StoredDelegation {
pub data: DelegationRecord,
pub status: DelegationStatus,
}Expand description
A delegation as stored in the database (status-agnostic).
When loading from the database, we don’t know the state at compile time.
Use the into_* methods to validate and convert to a typed delegation.
Fields
data: DelegationRecordstatus: DelegationStatusImplementations
Sourceimpl StoredDelegation
impl StoredDelegation
Sourcepub fn into_typed(self) -> LoadedDelegation
pub fn into_typed(self) -> LoadedDelegation
Convert to a typed delegation based on the stored status.
Sourcepub fn into_pending(self) -> Result<Delegation<Pending>, DelegationStateError>
pub fn into_pending(self) -> Result<Delegation<Pending>, DelegationStateError>
Try to convert to a pending delegation.
Sourcepub fn into_accepted(
self,
) -> Result<Delegation<DelegationAccepted>, DelegationStateError>
pub fn into_accepted( self, ) -> Result<Delegation<DelegationAccepted>, DelegationStateError>
Try to convert to an accepted delegation.
Sourcepub fn into_in_progress(
self,
) -> Result<Delegation<InProgress>, DelegationStateError>
pub fn into_in_progress( self, ) -> Result<Delegation<InProgress>, DelegationStateError>
Try to convert to an in-progress delegation.
Sourcepub fn data(&self) -> &DelegationRecord
pub fn data(&self) -> &DelegationRecord
Get the underlying data without state validation.
Sourcepub fn status(&self) -> DelegationStatus
pub fn status(&self) -> DelegationStatus
Get the current status.